@@ -152,6 +152,7 @@ void refresh_free (NiceAgent *agent, CandidateRefresh *cand)
   nice_debug ("Agent %p : Freeing candidate refresh %p", agent, cand);
 
   agent->refresh_list = g_slist_remove (agent->refresh_list, cand);
+  agent->pruning_refreshes = g_slist_remove (agent->pruning_refreshes, cand);
 
   if (cand->timer_source != NULL) {
     g_source_destroy (cand->timer_source);
@@ -199,7 +200,7 @@ static gboolean on_refresh_remove_timeout (NiceAgent *agent,
       agent_socket_send (cand->nicesock, &cand->server,
           stun_message_length (&cand->stun_message), (gchar *)cand->stun_buffer);
 
-      G_GNUC_FALLTHROUGH;
+      /* fall through */
     case STUN_USAGE_TIMER_RETURN_SUCCESS:
       agent_timeout_add_with_context (agent, &cand->tick_source,
           "TURN deallocate retransmission", stun_timer_remainder (&cand->timer),
@@ -285,11 +286,7 @@ typedef struct {
 static void on_refresh_removed (RefreshPruneAsyncData *data)
 {
   if (data->items_to_free == 0 || --(data->items_to_free) == 0) {
-    GSource *timeout_source = NULL;
-    agent_timeout_add_with_context (data->agent, &timeout_source,
-        "Async refresh prune", 0, data->cb, data->user_data);
-
-    g_source_unref (timeout_source);
+    data->cb (data->agent, data->user_data);
     g_free (data);
   }
 }
@@ -311,6 +308,8 @@ static void refresh_prune_async (NiceAgent *agent, GSList *refreshes,
     if (cand->disposing)
       continue;
 
+    agent->pruning_refreshes = g_slist_append (agent->pruning_refreshes, cand);
+
     timeout += agent->timer_ta;
     cand->disposing = TRUE;
     cand->destroy_cb = (GDestroyNotify) on_refresh_removed;
@@ -406,6 +405,34 @@ void refresh_prune_candidate_async (NiceAgent *agent,
   g_slist_free (refreshes);
 }
 
+/*
+ * Removes the candidate refreshes related to 'nicesock'.
+ */
+void refresh_prune_socket (NiceAgent *agent, NiceSocket *nicesock)
+{
+  GSList *i;
+
+  for (i = agent->refresh_list; i;) {
+    GSList *next = i->next;
+    CandidateRefresh *refresh = i->data;
+
+    if (refresh->nicesock == nicesock)
+      refresh_free(agent, refresh);
+
+    i = next;
+  }
+
+  for (i = agent->pruning_refreshes; i;) {
+    GSList *next = i->next;
+    CandidateRefresh *refresh = i->data;
+
+    if (refresh->nicesock == nicesock)
+      refresh_free(agent, refresh);
+
+    i = next;
+  }
+}
+
 /*
  * Adds a new local candidate. Implements the candidate pruning
  * defined in ICE spec section 4.1.3 "Eliminating Redundant
@@ -423,7 +450,26 @@ static gboolean priv_add_local_candidate_pruned (NiceAgent *agent, guint stream_
     if (nice_address_equal (&c->base_addr, &candidate->base_addr) &&
         nice_address_equal (&c->addr, &candidate->addr) &&
         c->transport == candidate->transport) {
-      nice_debug ("Candidate %p (component-id %u) redundant, ignoring.", candidate, component->id);
+      nice_debug ("Agent %p : s%d/c%d : cand %p redundant, ignoring.",
+          agent, stream_id, component->id, candidate);
+      return FALSE;
+    }
+
+    if (c->type == NICE_CANDIDATE_TYPE_RELAYED &&
+        candidate->type == NICE_CANDIDATE_TYPE_RELAYED &&
+        c->transport == candidate->transport &&
+        nice_address_equal_no_port (&c->addr, &candidate->addr)) {
+      nice_debug ("Agent %p : s%d/c%d : relay cand %p redundant, ignoring.",
+          agent, stream_id, component->id, candidate);
+      return FALSE;
+    }
+
+    if (c->type == NICE_CANDIDATE_TYPE_SERVER_REFLEXIVE &&
+        candidate->type == NICE_CANDIDATE_TYPE_SERVER_REFLEXIVE &&
+        c->transport == candidate->transport &&
+        nice_address_equal_no_port (&c->addr, &candidate->addr)) {
+      nice_debug ("Agent %p : s%d/c%d : srflx cand %p redundant, ignoring.",
+          agent, stream_id, component->id, candidate);
       return FALSE;
     }
   }
@@ -495,32 +541,51 @@ static void priv_assign_foundation (NiceAgent *agent, NiceCandidate *candidate)
       for (k = component->local_candidates; k; k = k->next) {
 	NiceCandidateImpl *n = k->data;
 
-        /* note: candidate must not on the local candidate list */
+        /* note: candidate must not be on the local candidate list */
 	g_assert (c != n);
 
-	if (candidate->type == n->c.type &&
-            candidate->transport == n->c.transport &&
-	    nice_address_equal_no_port (&candidate->base_addr, &n->c.base_addr) &&
-            (candidate->type != NICE_CANDIDATE_TYPE_RELAYED ||
-                priv_compare_turn_servers (c->turn, n->turn)) &&
-            !(agent->compatibility == NICE_COMPATIBILITY_GOOGLE &&
-                n->c.type == NICE_CANDIDATE_TYPE_RELAYED)) {
+	if (candidate->type != n->c.type)
+          continue;
+
+        if (candidate->transport != n->c.transport)
+          continue;
+
+        if (candidate->type == NICE_CANDIDATE_TYPE_RELAYED &&
+	    !nice_address_equal_no_port (&candidate->addr, &n->c.addr))
+          continue;
+
+        /* The base of a relayed candidate is that candidate itself, see
+         * sect 5.1.1.2. (Server Reflexive and Relayed Candidates) or
+         * ICE spec (RFC8445). It allows the relayed candidate from the
+         * same TURN server to share the same foundation.
+         */
+        if (candidate->type != NICE_CANDIDATE_TYPE_RELAYED &&
+            !nice_address_equal_no_port (&candidate->base_addr, &n->c.base_addr))
+          continue;
+
+        if (candidate->type == NICE_CANDIDATE_TYPE_RELAYED &&
+            !priv_compare_turn_servers (c->turn, n->turn))
+          continue;
+
+        if (candidate->type == NICE_CANDIDATE_TYPE_RELAYED &&
+            agent->compatibility == NICE_COMPATIBILITY_GOOGLE)
 	  /* note: currently only one STUN server per stream at a
 	   *       time is supported, so there is no need to check
 	   *       for candidates that would otherwise share the
 	   *       foundation, but have different STUN servers */
-	  g_strlcpy (candidate->foundation, n->c.foundation,
-              NICE_CANDIDATE_MAX_FOUNDATION);
-          if (n->c.username) {
-            g_free (candidate->username);
-            candidate->username = g_strdup (n->c.username);
-          }
-          if (n->c.password) {
-            g_free (candidate->password);
-            candidate->password = g_strdup (n->c.password);
-          }
-	  return;
-	}
+          continue;
+
+	g_strlcpy (candidate->foundation, n->c.foundation,
+            NICE_CANDIDATE_MAX_FOUNDATION);
+        if (n->c.username) {
+          g_free (candidate->username);
+          candidate->username = g_strdup (n->c.username);
+        }
+        if (n->c.password) {
+          g_free (candidate->password);
+          candidate->password = g_strdup (n->c.password);
+        }
+	return;
       }
     }
   }
@@ -646,13 +711,30 @@ priv_local_host_candidate_duplicate_port (NiceAgent *agent,
 
             nice_address_to_string (&candidate->addr, ip);
             nice_address_to_string (&c->addr, ip2);
-            nice_debug ("Agent %p: Local host %s candidate %s"
-                " for s%d:%d will use the same port %d as %s .", agent, ip,
+            nice_debug ("Agent %p: s%d/c%d: host candidate %s:[%s]:%u "
+                " will use the same port as %s:[%s]:%u", agent,
+                stream->id, component->id,
+                nice_candidate_transport_to_string (candidate->transport),
+                ip, nice_address_get_port (&candidate->addr),
                 nice_candidate_transport_to_string (c->transport),
-                stream->id, component->id, nice_address_get_port (&c->addr),
-                ip2);
+                ip2, nice_address_get_port (&c->addr));
             return FALSE;
           }
+          {
+            gchar ip[NICE_ADDRESS_STRING_LEN];
+            gchar ip2[NICE_ADDRESS_STRING_LEN];
+
+            nice_address_to_string (&candidate->addr, ip);
+            nice_address_to_string (&c->addr, ip2);
+            nice_debug ("Agent %p: s%d/c%d: host candidate %s:[%s]:%u "
+                " has the same port as %s:[%s]:%u from s%d/c%d", agent,
+                candidate->stream_id, candidate->component_id,
+                nice_candidate_transport_to_string (candidate->transport),
+                ip, nice_address_get_port (&candidate->addr),
+                nice_candidate_transport_to_string (c->transport),
+                ip2, nice_address_get_port (&c->addr),
+                stream->id, component->id);
+          }
 
           return TRUE;
         }
@@ -714,7 +796,7 @@ HostCandidateResult discovery_add_local_host_candidate (
   /* note: candidate username and password are left NULL as stream
      level ufrag/password are used */
   if (transport == NICE_CANDIDATE_TRANSPORT_UDP) {
-    nicesock = nice_udp_bsd_socket_new (address);
+    nicesock = nice_udp_bsd_socket_new (address, &error);
   } else if (transport == NICE_CANDIDATE_TRANSPORT_TCP_ACTIVE) {
     nicesock = nice_tcp_active_socket_new (agent->main_context, address);
   } else if (transport == NICE_CANDIDATE_TRANSPORT_TCP_PASSIVE) {
@@ -766,7 +848,7 @@ errors:
  *
  * @return pointer to the created candidate, or NULL on error
  */
-NiceCandidate*
+void
 discovery_add_server_reflexive_candidate (
   NiceAgent *agent,
   guint stream_id,
@@ -774,6 +856,7 @@ discovery_add_server_reflexive_candidate (
   NiceAddress *address,
   NiceCandidateTransport transport,
   NiceSocket *base_socket,
+  const NiceAddress *server_address,
   gboolean nat_assisted)
 {
   NiceCandidate *candidate;
@@ -783,7 +866,7 @@ discovery_add_server_reflexive_candidate (
   gboolean result = FALSE;
 
   if (!agent_find_component (agent, stream_id, component_id, &stream, &component))
-    return NULL;
+    return;
 
   candidate = nice_candidate_new (NICE_CANDIDATE_TYPE_SERVER_REFLEXIVE);
   c = (NiceCandidateImpl *) candidate;
@@ -809,6 +892,9 @@ discovery_add_server_reflexive_candidate (
         agent->reliable, nat_assisted);
   }
 
+  if (server_address != NULL)
+    c->stun_server = nice_address_dup (server_address);
+
   priv_generate_candidate_credentials (agent, candidate);
   priv_assign_foundation (agent, candidate);
 
@@ -820,8 +906,6 @@ discovery_add_server_reflexive_candidate (
     /* error: duplicate candidate */
     nice_candidate_free (candidate), candidate = NULL;
   }
-
-  return candidate;
 }
 
 /*
@@ -837,7 +921,8 @@ discovery_discover_tcp_server_reflexive_candidates (
   guint stream_id,
   guint component_id,
   NiceAddress *address,
-  NiceSocket *base_socket)
+  NiceSocket *base_socket,
+  const NiceAddress *server_addr)
 {
   NiceComponent *component;
   NiceStream *stream;
@@ -866,6 +951,7 @@ discovery_discover_tcp_server_reflexive_candidates (
           address,
           c->transport,
           ((NiceCandidateImpl *) c)->sockptr,
+          server_addr,
           FALSE);
     }
   }
@@ -885,7 +971,8 @@ discovery_add_relay_candidate (
   NiceAddress *address,
   NiceCandidateTransport transport,
   NiceSocket *base_socket,
-  TurnServer *turn)
+  TurnServer *turn,
+  uint32_t *lifetime)
 {
   NiceCandidate *candidate;
   NiceCandidateImpl *c;
@@ -938,8 +1025,11 @@ discovery_add_relay_candidate (
 
   priv_assign_foundation (agent, candidate);
 
-  if (!priv_add_local_candidate_pruned (agent, stream_id, component, candidate))
-    goto errors;
+  if (!priv_add_local_candidate_pruned (agent, stream_id, component, candidate)) {
+    if (lifetime)
+      *lifetime = 0;
+    return c;
+  }
 
   nice_component_attach_socket (component, relay_socket);
   agent_signal_new_candidate (agent, candidate);
@@ -1192,16 +1282,6 @@ static gboolean priv_discovery_tick_unlocked (NiceAgent *agent)
       if (nice_address_is_valid (&cand->server) &&
           (cand->type == NICE_CANDIDATE_TYPE_SERVER_REFLEXIVE ||
               cand->type == NICE_CANDIDATE_TYPE_RELAYED)) {
-        NiceComponent *component;
-
-        if (agent_find_component (agent, cand->stream_id,
-                cand->component_id, NULL, &component) &&
-            (component->state == NICE_COMPONENT_STATE_DISCONNECTED ||
-                component->state == NICE_COMPONENT_STATE_FAILED))
-          agent_signal_component_state_change (agent,
-					       cand->stream_id,
-					       cand->component_id,
-					       NICE_COMPONENT_STATE_GATHERING);
 
         if (cand->type == NICE_CANDIDATE_TYPE_SERVER_REFLEXIVE) {
           buffer_len = stun_usage_bind_create (&cand->stun_agent,
