@@ -289,7 +289,7 @@ static NiceCandidate *
 parse_candidate(char *scand, guint _stream_id)
 {
   NiceCandidate *cand = NULL;
-  NiceCandidateType ntype;
+  NiceCandidateType ntype = NICE_CANDIDATE_TYPE_HOST;
   gchar **tokens = NULL;
   guint i;
 
@@ -311,7 +311,7 @@ parse_candidate(char *scand, guint _stream_id)
   cand->component_id = 1;
   cand->stream_id = _stream_id;
   cand->transport = NICE_CANDIDATE_TRANSPORT_UDP;
-  strncpy(cand->foundation, tokens[0], NICE_CANDIDATE_MAX_FOUNDATION);
+  strncpy(cand->foundation, tokens[0], NICE_CANDIDATE_MAX_FOUNDATION - 1);
   cand->foundation[NICE_CANDIDATE_MAX_FOUNDATION - 1] = 0;
   cand->priority = atoi (tokens[1]);
 
