@@ -48,7 +48,14 @@
 #include <string.h>
 #include <assert.h>
 
-#ifdef HAVE_OPENSSL
+#if defined(USE_WIN32_CRYPTO)
+#include <malloc.h>
+typedef struct _StunKeyBlob {
+  BLOBHEADER header;
+  DWORD key_size;
+  BYTE key_data[0];
+} StunKeyBlob;
+#elif defined(HAVE_OPENSSL)
 #include <openssl/hmac.h>
 #include <openssl/sha.h>
 #else
@@ -64,7 +71,67 @@ void stun_sha1 (const uint8_t *msg, size_t len, size_t msg_len, uint8_t *sha,
 
   assert (len >= 44u);
 
-#ifdef HAVE_OPENSSL
+#if defined(USE_WIN32_CRYPTO)
+{
+  HCRYPTPROV prov;
+  size_t blob_size;
+  StunKeyBlob *blob;
+  BLOBHEADER *header;
+  HCRYPTKEY key_handle;
+  HCRYPTHASH hash;
+  HMAC_INFO info = {0};
+  DWORD sha_digest_len;
+
+#ifdef NDEBUG
+#define TRY(x) x;
+#else
+  BOOL success;
+#define TRY(x)                                  \
+  success = x;                                  \
+  assert (success);
+#endif
+
+  TRY (CryptAcquireContextW (&prov, NULL, NULL, PROV_RSA_FULL,
+        CRYPT_VERIFYCONTEXT));
+
+  blob_size = sizeof (StunKeyBlob) + keylen;
+  blob = _malloca (blob_size);
+  header = &blob->header;
+  header->bType = PLAINTEXTKEYBLOB;
+  header->bVersion = CUR_BLOB_VERSION;
+  header->reserved = 0;
+  header->aiKeyAlg = CALG_RC2;
+  blob->key_size = keylen;
+  memcpy (blob->key_data, key, keylen);
+  TRY (CryptImportKey (prov, (const BYTE *) blob, blob_size, 0,
+        CRYPT_IPSEC_HMAC_KEY, &key_handle));
+  _freea (blob);
+
+  TRY (CryptCreateHash (prov, CALG_HMAC, key_handle, 0, &hash));
+
+  info.HashAlgid = CALG_SHA1;
+  TRY (CryptSetHashParam (hash, HP_HMAC_INFO, (const BYTE *) &info, 0));
+
+  TRY (CryptHashData (hash, msg, 2, 0));
+  TRY (CryptHashData (hash, (const BYTE *) &fakelen, 2, 0));
+  TRY (CryptHashData (hash, msg + 4, len - 28, 0));
+
+  /* RFC 3489 specifies that the message's size should be 64 bytes,
+     and \x00 padding should be done */
+  if (padding && ((len - 24) % 64) > 0) {
+    uint16_t pad_size = 64 - ((len - 24) % 64);
+
+    TRY (CryptHashData (hash, pad_char, pad_size, 0));
+  }
+
+  sha_digest_len = 20;
+  TRY (CryptGetHashParam (hash, HP_HASHVAL, sha, &sha_digest_len, 0));
+
+  TRY (CryptDestroyHash (hash));
+  TRY (CryptDestroyKey (key_handle));
+  TRY (CryptReleaseContext (prov, 0));
+}
+#elif defined(HAVE_OPENSSL)
 {
 #ifdef NDEBUG
 #define TRY(x) x;
@@ -171,7 +238,26 @@ void stun_hash_creds (const uint8_t *realm, size_t realm_len,
   const uint8_t *realm_trimmed = priv_trim_var (realm, &realm_len);
   const uint8_t *colon = (uint8_t *)":";
 
-#ifdef HAVE_OPENSSL
+#if defined(USE_WIN32_CRYPTO)
+  HCRYPTPROV prov;
+  HCRYPTHASH hash;
+  DWORD md5_digest_len;
+
+  CryptAcquireContextW (&prov, NULL, NULL, PROV_RSA_FULL, CRYPT_VERIFYCONTEXT);
+  CryptCreateHash (prov, CALG_MD5, 0, 0, &hash);
+
+  CryptHashData (hash, username_trimmed, username_len, 0);
+  CryptHashData (hash, colon, 1, 0);
+  CryptHashData (hash, realm_trimmed, realm_len, 0);
+  CryptHashData (hash, colon, 1, 0);
+  CryptHashData (hash, password_trimmed, password_len, 0);
+
+  md5_digest_len = 16;
+  CryptGetHashParam (hash, HP_HASHVAL, md5, &md5_digest_len, 0);
+
+  CryptDestroyHash (hash);
+  CryptReleaseContext (prov, 0);
+#elif defined(HAVE_OPENSSL)
   EVP_MD_CTX *ctx;
 
 #if (OPENSSL_VERSION_NUMBER < 0x10100000L) || \
